@@ -14,7 +14,21 @@ use thiserror::Error;
 pub type ProviderReqId = DirectId<ProviderProtocol>;
 
 /// An identifier in a hierarchy of the node/metadata/stream.
-#[derive(Serialize, Deserialize, FromStr, Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
+#[derive(
+    Serialize,
+    Deserialize,
+    FromStr,
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    PartialOrd,
+    Ord,
+    Hash,
+    Default,
+    From,
+    Into,
+)]
 pub struct EntryId(String);
 
 impl AsRef<str> for EntryId {
@@ -35,12 +49,6 @@ impl From<&str> for EntryId {
     }
 }
 
-impl From<String> for EntryId {
-    fn from(value: String) -> Self {
-        Self(value)
-    }
-}
-
 impl fmt::Display for EntryId {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         fmt::Display::fmt(&self.0, f)
@@ -341,10 +349,14 @@ impl From<&str> for StreamType {
     }
 }
 
+// TODO: Consider removing and use `domain-scope` descriptions:
+// - for packs
+// - for internal server things
+// - for server ui controls
+// - etc.
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq)]
 pub struct Description {
     pub path: Path,
-    pub info: String,
     pub stream_type: StreamType,
 }
 
